antares.apps.subscription package — Antares 0.0.2 documentation

# antares.apps.subscription package

## Subpackages

- antares.apps.subscription.console package
  - Submodules
  - antares.apps.subscription.console.subscription_console module
  - Module contents
- antares.apps.subscription.exceptions package
  - Submodules
  - antares.apps.subscription.exceptions.subscription_exception module
  - Module contents
- antares.apps.subscription.manager package
  - Submodules
  - antares.apps.subscription.manager.subscription_manager module
  - Module contents
- antares.apps.subscription.migrations package
  - Submodules
  - antares.apps.subscription.migrations.0001_initial module
  - Module contents
- antares.apps.subscription.models package
  - Submodules
  - antares.apps.subscription.models.subscription_action module
  - antares.apps.subscription.models.subscription_action_parameter_map module
  - antares.apps.subscription.models.subscription_event module
  - Module contents
- antares.apps.subscription.service package
  - Module contents
- antares.apps.subscription.tests package
  - Module contents
- antares.apps.subscription.views package
  - Module contents

## Submodules

## antares.apps.subscription.admin module

## antares.apps.subscription.apps module

class `antares.apps.subscription.apps.` `SubscriptionConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'subscription'

## antares.apps.subscription.constants module

## antares.apps.subscription.urls module

## Module contents